guix-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

01/01: cdn: Change charlie's origin to ci.guix.info.


From: Chris Marusich
Subject: 01/01: cdn: Change charlie's origin to ci.guix.info.
Date: Sat, 4 May 2019 06:05:58 -0400 (EDT)

marusich pushed a commit to branch master
in repository maintenance.

commit 253a178a3aa62a2e8b817a0fa78ee58bf71ed24e
Author: Chris Marusich <address@hidden>
Date:   Sat May 4 02:21:30 2019 -0700

    cdn: Change charlie's origin to ci.guix.info.
    
    Now that ci.guix.info points directly to berlin, we can avoid
    depending on the guixsd.org zone by using ci.guix.info as the origin.
    
    * cdn/terraform/cloudfront.tf (locals) <default_behavior>
    <do_not_cache_behavior>: Change target_origin_id to "ci.guix.info".
---
 cdn/terraform/cloudfront.tf | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/cdn/terraform/cloudfront.tf b/cdn/terraform/cloudfront.tf
index 7d5a4ab..bbb3281 100644
--- a/cdn/terraform/cloudfront.tf
+++ b/cdn/terraform/cloudfront.tf
@@ -29,7 +29,7 @@ locals {
     # 
https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Expiration.html
     max_ttl = 31536000 # 365 days
     min_ttl = 0
-    target_origin_id = "berlin.guixsd.org"
+    target_origin_id = "ci.guix.info"
     # Historically, the build farm has allowed both HTTP and HTTPS.
     # We choose to maintain that policy here.  In the future, we
     # should consider changing this to "https-only".
@@ -57,17 +57,17 @@ locals {
     default_ttl = 0
     max_ttl = 0
     min_ttl = 0
-    target_origin_id = "berlin.guixsd.org"
+    target_origin_id = "ci.guix.info"
     viewer_protocol_policy = "allow-all"
   }
 }
 
 resource "aws_cloudfront_distribution" "charlie-distribution" {
   enabled = true
-  comment = "Distributed caching proxy for berlin.guixsd.org"
+  comment = "Distributed caching proxy for ci.guix.info"
   origin {
-    domain_name = "berlin.guixsd.org"
-    origin_id = "berlin.guixsd.org"
+    domain_name = "ci.guix.info"
+    origin_id = "ci.guix.info"
     custom_origin_config {
       http_port = 80 # Required, but not used.
       https_port = 443
@@ -92,7 +92,7 @@ resource "aws_cloudfront_distribution" "charlie-distribution" 
{
   # 
https://www.terraform.io/docs/providers/aws/r/cloudfront_distribution.html#retain_on_delete
   retain_on_delete = false
   # By default, don't cache anything.  This is useful because on
   # berlin.guixsd.org, we run Cuirass, which has many URLs we don't
   # want to cache.
   default_cache_behavior = ["${local.do_not_cache_behavior}"]
   # Cache all the relevant paths published by "guix publish".  See
@@ -92,7 +92,7 @@ resource "aws_cloudfront_distribution" "charlie-distribution" 
   retain_on_delete = false
   # By default, don't cache anything.  This is useful because on
-  # berlin.guixsd.org, we run Cuirass, which has many URLs we don't
+  # ci.guix.info, we run Cuirass, which has many URLs we don't
   # want to cache.
   default_cache_behavior = ["${local.do_not_cache_behavior}"]



reply via email to

[Prev in Thread] Current Thread [Next in Thread]